"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableBuilder = void 0;
const model_1 = require("../model");
class TableBuilder {
    constructor(name) {
        this.table = new model_1.Table(name);
    }
    table;
    text(id, name, unit) {
        this.table.addColumn(id, name, unit ?? '', model_1.ValueType.TEXT);
        return this;
    }
    num(id, name, unit) {
        this.table.addColumn(id, name, unit ?? '', model_1.ValueType.NUMBER);
        return this;
    }
    bool(id, name, unit) {
        this.table.addColumn(id, name, unit ?? '', model_1.ValueType.BOOLEAN);
        return this;
    }
    enum(id, name, unit) {
        this.table.addColumn(id, name, unit ?? '', model_1.ValueType.ENUM);
        return this;
    }
    mm(id, name) {
        return this.num(id, name, 'mm');
    }
    kg(id, name) {
        return this.num(id, name, 'kg');
    }
    min(id, name) {
        return this.num(id, name, 'min');
    }
    s(id, name) {
        return this.num(id, name, 's');
    }
    kg_dm3(id, name) {
        return this.num(id, name, 'kg/dm3');
    }
    m_min(id, name) {
        return this.num(id, name, 'm/min');
    }
    m_s(id, name) {
        return this.num(id, name, 'm/s');
    }
    W(id, name) {
        return this.num(id, name, 'W');
    }
    m_s2(id, name) {
        return this.num(id, name, 'm/s2');
    }
    Hz(id, name) {
        return this.num(id, name, 'Hz');
    }
    bar(id, name) {
        return this.num(id, name, 'bar');
    }
    mm2(id, name) {
        return this.num(id, name, 'mm2');
    }
    deg(id, name) {
        return this.num(id, name, 'deg');
    }
    data(values) {
        if (Array.isArray(values[0])) {
            values.forEach((v) => {
                if (!Array.isArray(v))
                    throw new Error('Invalid data - expected array of arrays');
                this.table.addDataSet().values = v.map((x) => `${x}`);
            });
        }
        else
            this.table.addDataSet().values = values.map((x) => `${x}`);
        return this;
    }
}
exports.TableBuilder = TableBuilder;
//# sourceMappingURL=TableBuilder.js.map