import { DataSet } from './DataSet';
export interface DataSetValue<T> {
    isDefined: boolean;
    value: T;
}
export declare class DataSetString implements DataSetValue<string> {
    private dataset;
    private id;
    private defaultValue;
    constructor(dataset: DataSet, id: number, defaultValue: string);
    get isDefined(): boolean;
    get value(): string;
    set value(v: string);
}
export declare class DataSetNumber implements DataSetValue<number> {
    private dataset;
    private id;
    private defaultValue;
    constructor(dataset: DataSet, id: number, defaultValue: number);
    get isDefined(): boolean;
    get value(): number;
    set value(v: number);
}
export declare class DataSetBool implements DataSetValue<boolean> {
    private dataset;
    private id;
    private defaultValue;
    constructor(dataset: DataSet, id: number, defaultValue: boolean);
    get isDefined(): boolean;
    get value(): boolean;
    set value(v: boolean);
}
export declare class DataSetAny<T> implements DataSetValue<T> {
    private dataset;
    private id;
    private defaultValue;
    private read;
    private write;
    constructor(dataset: DataSet, id: number, defaultValue: T, read: (value: string, unit: string) => T, write: (value: T, unit: string) => string);
    get isDefined(): boolean;
    get value(): T;
    set value(v: T);
}
export declare class DataSetUnit extends DataSetAny<number> {
    constructor(dataset: DataSet, id: number, defaultValue: number, factorsByUnit: Record<string, number>);
}
export declare class DataSetMillimeter extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetSquareMillimeter extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetKilogram extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetMinutes extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetSeconds extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetKilogramPerLiter extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetMetersPerMinute extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetMetersPerSecond extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetWatt extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetMetersPerSquareSeconds extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetHertz extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetBar extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
export declare class DataSetDegrees extends DataSetUnit {
    constructor(dataset: DataSet, id: number, defaultValue: number);
}
