"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataSetDegrees = exports.DataSetBar = exports.DataSetHertz = exports.DataSetMetersPerSquareSeconds = exports.DataSetWatt = exports.DataSetMetersPerSecond = exports.DataSetMetersPerMinute = exports.DataSetKilogramPerLiter = exports.DataSetSeconds = exports.DataSetMinutes = exports.DataSetKilogram = exports.DataSetSquareMillimeter = exports.DataSetMillimeter = exports.DataSetUnit = exports.DataSetAny = exports.DataSetBool = exports.DataSetNumber = exports.DataSetString = void 0;
class DataSetString {
    dataset;
    id;
    defaultValue;
    constructor(dataset, id, defaultValue) {
        this.dataset = dataset;
        this.id = id;
        this.defaultValue = defaultValue;
    }
    get isDefined() {
        return this.dataset.hasId(this.id);
    }
    get value() {
        return this.dataset.byId(this.id) ?? this.defaultValue;
    }
    set value(v) {
        this.dataset.trySetById(this.id, v);
    }
}
exports.DataSetString = DataSetString;
class DataSetNumber {
    dataset;
    id;
    defaultValue;
    constructor(dataset, id, defaultValue) {
        this.dataset = dataset;
        this.id = id;
        this.defaultValue = defaultValue;
    }
    get isDefined() {
        return this.dataset.hasId(this.id);
    }
    get value() {
        return this.dataset.numberById(this.id) ?? this.defaultValue;
    }
    set value(v) {
        this.dataset.trySetNumberById(this.id, v);
    }
}
exports.DataSetNumber = DataSetNumber;
class DataSetBool {
    dataset;
    id;
    defaultValue;
    constructor(dataset, id, defaultValue) {
        this.dataset = dataset;
        this.id = id;
        this.defaultValue = defaultValue;
    }
    get isDefined() {
        return this.dataset.hasId(this.id);
    }
    get value() {
        return this.dataset.boolById(this.id) ?? this.defaultValue;
    }
    set value(v) {
        this.dataset.trySetBoolById(this.id, v);
    }
}
exports.DataSetBool = DataSetBool;
class DataSetAny {
    dataset;
    id;
    defaultValue;
    read;
    write;
    constructor(dataset, id, defaultValue, read, write) {
        this.dataset = dataset;
        this.id = id;
        this.defaultValue = defaultValue;
        this.read = read;
        this.write = write;
    }
    get isDefined() {
        return this.dataset.hasId(this.id);
    }
    get value() {
        const index = this.dataset.columnDescriptions.indexById(this.id);
        if (index < 0) {
            return this.defaultValue;
        }
        // eslint-disable-next-line security/detect-object-injection
        const value = this.dataset.values[index];
        if (typeof value === 'undefined') {
            return this.defaultValue;
        }
        // eslint-disable-next-line security/detect-object-injection
        return this.read(value, this.dataset.columnDescriptions.columns[index].unit);
    }
    set value(v) {
        const index = this.dataset.columnDescriptions.indexById(this.id);
        if (index >= 0) {
            // eslint-disable-next-line security/detect-object-injection
            this.dataset.values[index] = this.write(v, this.dataset.columnDescriptions.columns[index].unit);
        }
    }
}
exports.DataSetAny = DataSetAny;
class DataSetUnit extends DataSetAny {
    constructor(dataset, id, defaultValue, factorsByUnit) {
        function getFactor(unit) {
            // eslint-disable-next-line security/detect-object-injection
            const factor = factorsByUnit[unit];
            if (!factor) {
                throw new Error(`Unknown unit ${unit}`);
            }
            return factor;
        }
        function read(value, unit) {
            const number = +value;
            if (Number.isNaN(number)) {
                throw new Error(`Invalid number ${value}`);
            }
            return number * getFactor(unit);
        }
        function write(v, unit) {
            return `${v / getFactor(unit)}`;
        }
        super(dataset, id, defaultValue, read, write);
    }
}
exports.DataSetUnit = DataSetUnit;
class DataSetMillimeter extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            nm: 1e-6,
            um: 1e-3,
            µm: 1e-3,
            mm: 1,
            cm: 10,
            dm: 100,
            m: 1000,
            in: 25.4,
            ft: 304.8,
        });
    }
}
exports.DataSetMillimeter = DataSetMillimeter;
class DataSetSquareMillimeter extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            nm2: 1e-12,
            um2: 1e-6,
            µm2: 1e-6,
            mm2: 1,
            cm2: 1e2,
            dm2: 1e4,
            m2: 1e6,
            in2: 25.4 * 25.4,
            ft2: 304.8 * 304.8,
        });
    }
}
exports.DataSetSquareMillimeter = DataSetSquareMillimeter;
class DataSetKilogram extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            g: 1e-3,
            lb: 0.453592,
            kg: 1,
        });
    }
}
exports.DataSetKilogram = DataSetKilogram;
class DataSetMinutes extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            s: 1 / 60,
            sec: 1 / 60,
            min: 1,
            h: 60,
        });
    }
}
exports.DataSetMinutes = DataSetMinutes;
class DataSetSeconds extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            s: 1,
            sec: 1,
            min: 60,
            h: 60 * 60,
        });
    }
}
exports.DataSetSeconds = DataSetSeconds;
class DataSetKilogramPerLiter extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            'kg/m3': 1e-3,
            'kg/dm3': 1,
            'g/cm3': 1,
            'lb/in3': 0.453592 / 0.254 / 0.254 / 0.254,
        });
    }
}
exports.DataSetKilogramPerLiter = DataSetKilogramPerLiter;
class DataSetMetersPerMinute extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            'm/min': 1,
        });
    }
}
exports.DataSetMetersPerMinute = DataSetMetersPerMinute;
class DataSetMetersPerSecond extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            'mm/s': 1e-3,
            'in/s': 0.0254,
            'm/min': 1 / 60,
            'mm/min': 1e-3 / 60,
            'in/min': 0.0254 / 60,
        });
    }
}
exports.DataSetMetersPerSecond = DataSetMetersPerSecond;
class DataSetWatt extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            W: 1,
        });
    }
}
exports.DataSetWatt = DataSetWatt;
class DataSetMetersPerSquareSeconds extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            'mm/s2': 1e-3,
            'in/s2': 0.0254,
            'm/s2': 1,
        });
    }
}
exports.DataSetMetersPerSquareSeconds = DataSetMetersPerSquareSeconds;
class DataSetHertz extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            Hz: 1,
        });
    }
}
exports.DataSetHertz = DataSetHertz;
class DataSetBar extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            bar: 1,
        });
    }
}
exports.DataSetBar = DataSetBar;
class DataSetDegrees extends DataSetUnit {
    constructor(dataset, id, defaultValue) {
        super(dataset, id, defaultValue, {
            deg: 1,
            rad: 180 / Math.PI,
        });
    }
}
exports.DataSetDegrees = DataSetDegrees;
//# sourceMappingURL=DataSetValues.js.map