import 'reflect-metadata';
import { ColumnDescriptions } from './ColumnDescriptions';
import { DataSet } from './DataSet';
import { DataSetMillimeter, DataSetKilogram, DataSetMinutes, DataSetSeconds, DataSetKilogramPerLiter, DataSetMetersPerMinute, DataSetWatt, DataSetMetersPerSquareSeconds, DataSetHertz, DataSetBar, DataSetSquareMillimeter, DataSetDegrees, DataSetMetersPerSecond } from './DataSetValues';
declare const dataSetClassByUnit: {
    mm: typeof DataSetMillimeter;
    kg: typeof DataSetKilogram;
    min: typeof DataSetMinutes;
    s: typeof DataSetSeconds;
    'kg/dm3': typeof DataSetKilogramPerLiter;
    'm/min': typeof DataSetMetersPerMinute;
    'm/s': typeof DataSetMetersPerSecond;
    W: typeof DataSetWatt;
    'm/s2': typeof DataSetMetersPerSquareSeconds;
    Hz: typeof DataSetHertz;
    bar: typeof DataSetBar;
    mm2: typeof DataSetSquareMillimeter;
    deg: typeof DataSetDegrees;
};
interface LstDataOptions<T> {
    name?: string;
    unit?: keyof typeof dataSetClassByUnit;
    read?: (value: string, unit: string) => T;
    write?: (value: T, unit: string) => string;
    default?: T;
}
export declare function LstData<T>(id: number, options?: LstDataOptions<T>): (target: any, propertyName: string) => void;
interface LstDataAttachmentOptions<T> {
    read: (data: string[]) => T;
    write: (value: T) => string[];
}
export declare function LstDataAttachment<T>(options?: LstDataAttachmentOptions<T>): (target: any, propertyName: string) => void;
export declare function newColumnDescriptions<T, ARGS extends any[]>(factory: new (...args: ARGS) => T): ColumnDescriptions;
export declare function newDataSet<T, ARGS extends any[]>(factory: new (...args: ARGS) => T, dataSet?: DataSet, ...args: ARGS): T & {
    $dataSet: DataSet;
};
export declare function loadDataSet<T, ARGS extends any[]>(factory: new (...args: ARGS) => T, dataSet: DataSet, ...args: ARGS): T;
export {};
