"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadDocument = exports.newDocument = exports.LstTable = void 0;
const LstData_1 = require("./LstData");
const lstTableMap = new WeakMap();
function LstTable(name, dataSetType) {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    return function (target, propertyName) {
        const type = Reflect.getMetadata('design:type', target, propertyName);
        if (type !== Array) {
            throw new Error(`Expect @LstTable for ${propertyName} to be used with an array but found ${type}`);
        }
        const tableDef = { name: name.toUpperCase(), dataSetType };
        const map = lstTableMap.get(target);
        if (map) {
            // eslint-disable-next-line security/detect-object-injection
            map[propertyName] = tableDef;
        }
        else {
            lstTableMap.set(target, { [propertyName]: tableDef });
        }
    };
}
exports.LstTable = LstTable;
function loadIntoDocument(type, instance, document, dataSetFactory) {
    const map = lstTableMap.get(type);
    if (!map) {
        throw new Error(`Type ${type.name} is not decorated with @LstTable decorator.`);
    }
    Object.entries(map).forEach(([propertyName, tableDef]) => {
        const array = instance[propertyName] ?? (instance[propertyName] = []);
        document.tables
            .filter((table) => table.name.toUpperCase() === tableDef.name)
            .forEach((table) => {
            table.dataSets.forEach((dataSet) => array.push(dataSetFactory(tableDef.dataSetType, dataSet)));
        });
    });
}
function newDocument(constructor, document, ...args) {
    const instance = new constructor(...args);
    instance.$document = document;
    loadIntoDocument(constructor.prototype, instance, document, LstData_1.newDataSet);
    return instance;
}
exports.newDocument = newDocument;
function loadDocument(constructor, document, ...args) {
    const instance = new constructor(...args);
    loadIntoDocument(constructor.prototype, instance, document, LstData_1.loadDataSet);
    return instance;
}
exports.loadDocument = loadDocument;
//# sourceMappingURL=LstTable.js.map