"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Parser = void 0;
/* eslint-disable @typescript-eslint/no-non-null-assertion */
const Constants_1 = require("./Constants");
class Parser {
    source;
    pos;
    get isOk() {
        return this.pos < this.source.length;
    }
    get isAtLineEnd() {
        return this.char === '\r' || this.char === '\n';
    }
    token = '';
    char = null;
    lineNumber;
    constructor(source) {
        this.source = source;
        this.pos = -1;
        this.lineNumber = 1;
        this.readNextChar();
    }
    tryReadContentLine() {
        this.trySkipWhiteSpacesCommentsOrLineEnd();
        return this.tryReadLine();
    }
    tryReadLine() {
        const success = this.isOk;
        const p0 = this.pos;
        while (this.isOk && !this.isAtLineEnd) {
            this.readNextChar();
        }
        this.token = this.source.substring(p0, this.pos);
        if (this.isOk) {
            this.readNextChar(); // Skip end-of-line.
        }
        return success;
    }
    trySkipWhiteSpacesCommentsOrLineEnd() {
        do {
            this.trySkipWhiteSpacesOrLineEnd();
        } while (this.isOk && this.char === Constants_1.Constants.COMMENT && this.tryReadLine() && this.isOk);
        this.token = '';
    }
    trySkipWhiteSpacesOrLineEnd() {
        while (this.isOk && /\s/.test(this.char)) {
            this.readNextChar();
        }
    }
    trySkipWhiteSpaces() {
        while (this.isOk && !this.isAtLineEnd && /\s/.test(this.char)) {
            this.readNextChar();
        }
    }
    tryReadValueOrString() {
        this.trySkipWhiteSpaces();
        if (!this.isOk) {
            return false;
        }
        if (this.char === Constants_1.Constants.Table.STRING_SEPARATOR) {
            this.readString();
        }
        else if (this.char === Constants_1.Constants.Table.FIELD_SEPARATOR) {
            this.token = Constants_1.Constants.Table.EMPTY_FIELD_TOKEN;
        }
        else {
            this.readValue();
        }
        return true;
    }
    readValue() {
        this.trySkipWhiteSpaces();
        const p0 = this.pos;
        while (this.isOk && this.char !== Constants_1.Constants.Table.FIELD_SEPARATOR && !/\s/.test(this.char)) {
            this.readNextChar();
        }
        this.token = this.source.substring(p0, this.pos);
    }
    readString() {
        this.trySkipWhiteSpaces();
        if (this.char !== Constants_1.Constants.Table.STRING_SEPARATOR) {
            throw new Error(`Expected string but found ${this.char} in LST line ${this.lineNumber}.`);
        }
        this.readNextChar();
        const p0 = this.pos;
        while (this.isOk && this.char !== Constants_1.Constants.Table.STRING_SEPARATOR) {
            this.readNextChar();
        }
        this.token = this.source.substring(p0, this.pos);
        if (!this.isOk) {
            throw new Error(`Missing end of string in LST line ${this.lineNumber}.`);
        }
        this.readNextChar(); // Skip '\''.
    }
    tryReadFieldSeparator() {
        this.trySkipWhiteSpaces();
        if (this.char !== Constants_1.Constants.Table.FIELD_SEPARATOR) {
            return false;
        }
        this.readNextChar();
        return true;
    }
    readNextChar() {
        if (this.isOk) {
            if (++this.pos === this.source.length) {
                this.char = null;
            }
            else {
                let next = this.source[this.pos];
                if (this.isAtLineEnd) {
                    ++this.lineNumber;
                    if (this.char === '\r' && next === '\n') {
                        if (++this.pos === this.source.length) {
                            next = null;
                        }
                        else {
                            next = this.source[this.pos];
                        }
                    }
                }
                this.char = next;
            }
        }
    }
}
exports.Parser = Parser;
//# sourceMappingURL=Parser.js.map