"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableLineReader = void 0;
const Constants_1 = require("./Constants");
class TableLineReader {
    parser;
    connectFields = false;
    fields = [];
    constructor(parser) {
        this.parser = parser;
    }
    read() {
        this.fields = [];
        this.parser.trySkipWhiteSpacesCommentsOrLineEnd();
        while (this.parser.tryReadValueOrString()) {
            this.addField(this.parser.token);
            if (!this.tryReadLineOrFieldConnector())
                break;
            if (!this.parser.tryReadFieldSeparator())
                break;
            if (!this.tryReadLineOrFieldConnector()) {
                this.addField(Constants_1.Constants.Table.EMPTY_FIELD_TOKEN);
                break;
            }
        }
    }
    addField(value) {
        if (this.connectFields) {
            if (this.fields.length === 0) {
                throw new Error(`Corrupt field entry in LST line ${this.parser.lineNumber}.`);
            }
            this.fields[this.fields.length - 1] += value;
        }
        else {
            this.fields.push(value);
        }
    }
    tryReadLineOrFieldConnector() {
        this.connectFields = false;
        let isWithinLine = true;
        this.parser.trySkipWhiteSpaces();
        if (this.parser.isAtLineEnd) {
            this.parser.readNextChar();
            this.parser.trySkipWhiteSpaces();
            if (!this.parser.isOk) {
                isWithinLine = false;
            }
            else if (this.parser.char === Constants_1.Constants.Table.FIELD_CONNECTOR) {
                this.connectFields = true;
                this.parser.readNextChar();
            }
            else if (this.parser.char === Constants_1.Constants.Table.LINE_CONNECTOR) {
                this.parser.readNextChar();
            }
            else {
                isWithinLine = false;
            }
        }
        return isWithinLine;
    }
}
exports.TableLineReader = TableLineReader;
//# sourceMappingURL=TableLineReader.js.map